CREATE TABLE [dbo].[IISBM_config] (
	[name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[monthly_bandwidth] [numeric](18, 0) NOT NULL ,
	[action_on_overage] [int] NULL ,
	[warn_email_to] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[warn_email_from] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[warn_email_subject] [varchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[IISBM_hit] (
	[id] [int] IDENTITY (1, 1) NOT NULL ,
	[server_name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[instance_id] [numeric](18, 0) NULL ,
	[instance] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[sent] [numeric](18, 0) NULL ,
	[received] [numeric](18, 0) NULL ,
	[total] [numeric](18, 0) NULL ,
	[get_hits] [int] NULL ,
	[post_hits] [int] NULL ,
	[date_created] [datetime] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[IISBM_log] (
	[id] [int] IDENTITY (1, 1) NOT NULL ,
	[server_name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[message] [text] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[date_created] [datetime] NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

ALTER TABLE [dbo].[IISBM_config] WITH NOCHECK ADD 
	CONSTRAINT [PK_IISBM_config] PRIMARY KEY  CLUSTERED 
	(
		[name]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[IISBM_hit] WITH NOCHECK ADD 
	CONSTRAINT [PK_service_log] PRIMARY KEY  CLUSTERED 
	(
		[id]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[IISBM_log] WITH NOCHECK ADD 
	CONSTRAINT [PK_IISBM_log] PRIMARY KEY  CLUSTERED 
	(
		[id]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[IISBM_config] ADD 
	CONSTRAINT [DF_IISBM_config_monthly_bandwidth] DEFAULT (0) FOR [monthly_bandwidth],
	CONSTRAINT [DF_IISBM_config_action_on_overage] DEFAULT (0) FOR [action_on_overage]
GO

ALTER TABLE [dbo].[IISBM_hit] ADD 
	CONSTRAINT [DF_service_log_date_Created] DEFAULT (getdate()) FOR [date_created]
GO

ALTER TABLE [dbo].[IISBM_log] ADD 
	CONSTRAINT [DF_service_log2_date_created] DEFAULT (getdate()) FOR [date_created]
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS OFF 
GO

CREATE PROCEDURE dbo.iisbm_condense_log 
@date_start datetime,
@date_end datetime,
@interval varchar(20) = 'daily'
AS
BEGIN TRANSACTION
	DECLARE @maxid int

	-- find out what the highest id is so that we can easily remove the old entries after the new
	-- consolidated entries are created
	
	SELECT TOP 1 @maxid = id
	FROM iisbm_hit
	ORDER BY id DESC

	IF @interval = 'daily'
	BEGIN
		SELECT *
		INTO #temp_daily
		FROM (
			SELECT     server_name, instance_id, instance, DATEPART(yyyy, date_created) AS year, DATEPART(m, date_created) AS month, DATEPART(d, date_created) AS day,
			                      SUM(sent) AS sent, SUM(received) AS received, SUM(total) AS total, SUM(get_hits) AS get_hits, SUM(post_hits) 
			                      AS post_hits
			FROM         IISBM_hit
			WHERE date_created BETWEEN @date_start AND @date_end
			GROUP BY server_name, instance_id, instance, DATEPART(yyyy, date_created), DATEPART(m, date_created), DATEPART(d, date_created)
		) drvtable
		ORDER BY year, month, day, instance

		INSERT INTO IISBM_hit
		(server_name, instance_id, instance, sent, received, total, get_hits, post_hits, date_created)
		SELECT 
			server_name, instance_id, instance, sent, received, total, get_hits, post_hits,
			Convert(varchar, month) + '/' + Convert(varchar, day) + '/' + Convert(varchar, year) + ' 12:00AM'
		FROM #temp_daily

		DROP TABLE #temp_daily

		DELETE FROM IISBM_hit
		WHERE date_created
		BETWEEN @date_start AND @date_end
		AND id <= @maxid
	END

	IF @interval = 'hourly'
	BEGIN
		SELECT *
		INTO #temp_hourly
		FROM (
			SELECT     server_name, instance_id, instance, DATEPART(yyyy, date_created) AS year, DATEPART(m, date_created) AS month, DATEPART(d, date_created) AS day, 
				      DATEPART(hh, date_created) AS hour, SUM(sent) AS sent, SUM(received) AS received, SUM(total) AS total, SUM(get_hits) AS get_hits, SUM(post_hits) 
			                      AS post_hits
			FROM         IISBM_hit
			WHERE date_created BETWEEN @date_start AND @date_end
			GROUP BY server_name, instance_id, instance, DATEPART(yyyy, date_created), DATEPART(m, date_created), DATEPART(d, date_created), DATEPART(hh, date_created)
		) drvtable
		ORDER BY year, month, day, hour, instance

		INSERT INTO IISBM_hit
		(server_name, instance_id, instance, sent, received, total, get_hits, post_hits, date_created)
		SELECT 
			server_name, instance_id, instance, sent, received, total, get_hits, post_hits,
			Convert(varchar, month) + '/' + Convert(varchar, day) + '/' + Convert(varchar, year) + ' ' + Convert(varchar, hour) + ':00'
		FROM #temp_hourly

		DROP TABLE #temp_hourly

		DELETE FROM IISBM_hit
		WHERE date_created
		BETWEEN @date_start AND @date_end
		AND id <= @maxid
	END
COMMIT TRANSACTION
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

CREATE PROCEDURE dbo.iisbm_report_instancebyday
@instance varchar(50) = '%',
@date_start datetime = '1/1/1900',
@date_end datetime = NULL
AS
	-- set @date_end to right now if it wasn't passed
	SET @date_end = Coalesce(@date_end, GetDate())

	SELECT     DATEPART(yyyy, date_created) AS year, DATEPART(m, date_created) AS month, DATEPART(d, date_created) AS day, 
		      SUM(sent) AS sent, SUM(received) AS received, SUM(total) AS total, SUM(get_hits) AS get_hits, SUM(post_hits) 
	                      AS post_hits
	FROM         IISBM_hit
	WHERE date_created BETWEEN @date_start AND @date_end
	AND instance LIKE @instance
	GROUP BY DATEPART(yyyy, date_created), DATEPART(m, date_created), DATEPART(d, date_created)
 	ORDER BY year, month, day
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

CREATE PROCEDURE dbo.iisbm_report_instancebyhour 
@instance varchar(50) = '%',
@date_start datetime = '1/1/1900',
@date_end datetime = NULL
AS
	-- set @date_end to right now if it wasn't passed
	SET @date_end = Coalesce(@date_end, GetDate())

	SELECT    DATEPART(yyyy, date_created) AS year, DATEPART(m, date_created) AS month, DATEPART(d, date_created) AS day, 
		      DATEPART(hh, date_created) AS hour, SUM(sent) AS sent, SUM(received) AS received, SUM(total) AS total, SUM(get_hits) AS get_hits, SUM(post_hits) 
	                      AS post_hits
	FROM         IISBM_hit
	WHERE date_created BETWEEN @date_start AND @date_end
	AND instance LIKE @instance
	GROUP BY  DATEPART(yyyy, date_created), DATEPART(m, date_created), DATEPART(d, date_created), DATEPART(hh, date_created)
 	ORDER BY year, month, day, hour
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

CREATE PROCEDURE dbo.iisbm_report_instancebymonth
@instance varchar(50) = '%',
@date_start datetime = '1/1/1900',
@date_end datetime = NULL
AS
	-- set @date_end to right now if it wasn't passed
	SET @date_end = Coalesce(@date_end, GetDate())
	SELECT null AS aaa, instance, DATEPART(yyyy, date_created), DATEPART(m, date_created), Sum(sent) AS sent, Sum(received) AS received, Sum(total) AS total, Sum(get_hits) AS get_hits, Sum(post_hits) AS post_hits
	FROM iisbm_hit
	WHERE date_created BETWEEN @date_start AND @date_end
	AND instance LIKE @instance
	GROUP BY instance, DATEPART(yyyy, date_created), DATEPART(m, date_created)
	ORDER BY 8 DESC
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

CREATE PROCEDURE dbo.iisbm_report_instancedetail 
@instance varchar(50) = '%',
@date_start datetime = '1/1/1900',
@date_end datetime = NULL
AS
	-- set @date_end to right now if it wasn't passed
	SET @date_end = Coalesce(@date_end, GetDate())

	SELECT 'Last 7' AS range, instance, Sum(sent) AS sent, Sum(received) AS received, Sum(total) AS total, Sum(get_hits) AS get_hits, Sum(post_hits) AS post_hits
	FROM iisbm_hit
	WHERE date_created BETWEEN @date_start AND @date_end
	AND DateDiff(d, date_created, GetDate()) <= 7
	AND instance LIKE @instance
	GROUP BY instance
	UNION ALL
	SELECT 'Last 8 - 14' AS range, instance, Sum(sent) AS sent, Sum(received) AS received, Sum(total) AS total, Sum(get_hits) AS get_hits, Sum(post_hits) AS post_hits
	FROM iisbm_hit
	WHERE date_created BETWEEN @date_start AND @date_end
	AND DateDiff(d, date_created, GetDate()) <= 14 AND DateDiff(d, date_created, GetDate()) > 7
	AND instance LIKE @instance
	GROUP BY instance
	ORDER BY instance
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

